@@ -186,9 +186,10 @@ class Git extends Models\Adapter
 				continue;
 			}
 
-			// Moved setting date to this location so that the date always shows even if modified was not selected as the sorting mechanism.
 			// Need to get extra metadata (slower)
-			$file->set('date', $this->_file($file, $dirPath, 'date'));
+			// This method was causing quite a bit of sluggishness (if only I paid attention to the comment above). 
+			// I've instead added retrieving the date with filemtime to the defaults() method in the File model.
+			// $file->set('date', $this->_file($file, $dirPath, 'date'));
 
 			// Check for remote connections
 			$syncRecord = null;
@@ -820,13 +821,12 @@ class Git extends Models\Adapter
 				return 0;
 			}
 
-			exec('du -sk ' . $where, $out);
+			exec('du -sb --exclude=.git ' . $where, $out);
 
 			if ($out && isset($out[0]))
 			{
 				$dir = $git == true ? '.git' : '.';
-				$kb = str_replace($dir, '', trim($out[0]));
-				$used = $kb * 1024;
+				$used = str_replace($dir, '', trim($out[0]));
 			}
 		}
 
